# -*- coding: utf-8 -*-
import random, string
from django.db import migrations

from wagtail.fields import StreamValue
from waggylabs.blocks.base_body import BaseBodyBlock
from waggylabs.blocks.sidebar import SidebarBlock


def create_sitepage(apps, schema_editor):
    """Creates default WaggyLabs page."""
    
    # Get models
    ContentType = apps.get_model("contenttypes.ContentType")
    Page = apps.get_model("wagtailcore.Page")
    Site = apps.get_model("wagtailcore.Site")
    Locale = apps.get_model("wagtailcore.Locale")
    SitePage = apps.get_model("waggylabs.SitePage")

    # Delete the default homepage
    # If migration is run multiple times, it may have already been deleted
    Page.objects.filter(id=2).delete()

    # Create content type for sitepage model
    sitepage_content_type, __ = ContentType.objects.get_or_create(
        model="sitepage", app_label="waggylabs"
    )
    
    # Get default locale
    locale = Locale.objects.first()

    # Create a new sitepage
    sitepage = SitePage.objects.create(
        title="Home",
        draft_title="Home",
        slug="home",
        content_type=sitepage_content_type,
        locale=locale,
        path="00010001",
        depth=2,
        numchild=0,
        url_path="/home/",
        show_sidebar=True,
        body=StreamValue(
            BaseBodyBlock(),
            [
                {'type': 'text', 'value': "This is the demo page of the Waggy Labs content management systems designed to create websites for research groups and sicentific blogs! This page contains the demostration of options and possibilities to create complex content pages with TeX style equations and references with ease! It is done using a [markdown](https://www.markdownguide.org/) editor enhanced with easy entering TeX equations, references to figures, equations, quotes, tables and citations using standed TeX \\ref and \\cite commands. Equation are rendered using [MathJax](https://mathjax.org) allowing entering any type of math. :avocado:\r\n\r\nHere is a quick example. Consider the Maxwell's equations below (Eqs \\eqref{eq-M1}-\\eqref{eq-M4})\\cite{cite1,cite0}. In the absence of charges (i.e., the source of field is far away) and in the CGS unit system ($1/c^2 = \\mu_0 \\epsilon_0$) they read as \r\n\\begin{align}\r\n\\label{eq-M1}\r\n& \\mathbf{\\nabla \\cdot E} = 0 \\\\\r\n& \\mathbf{\\nabla \\cdot B} = 0 \\\\\r\n& \\mathbf{\\nabla \\times E} = \\frac{1}{c} \\frac{\\partial \\mathbf{B}}{\\partial t} \\\\\r\n\\label{eq-M4}\r\n& \\mathbf{\\nabla \\times B} = \\frac{4\\pi}{c}\\mathbf{j} + \\frac{1}{c}\\frac{\\partial \\mathbf{E}}{\\partial t}\r\n\\end{align}\r\n\r\nBelow, we go through different content items that can be added on the Page in the editing interface provided by beautiful [Wagtail CMS](https://wagtail.org) and enhanced by Waggy Labs.\r\n\r\nHere is the list of content items:\r\n\r\n1. Accordion\r\n2. Quote\r\n3. Card grid\r\n4. Picture carousel\r\n5. Content in columns\r\n6. Embedding content from other websites including video\r\n7. Standalone equation. It allows adding a caption to the equation to be displayed when the equation is opened in a separate dialog for preview.\r\n8. Figure\r\n9. Listing to present code snippets\r\n10. Table in which equations and markdown content can be added to the cells.\r\n11. Table as picture.\r\n\r\n## Header 2\r\n### Header 3\r\n\r\nWaggy Labs is powered by [Bootstrap](https://getbootstrap.com/) to present the content. Thus it supports customization by uploading pre-made CSS files that can totally change the appearnce of a website run by Waggy Labs.\r\n\r\n#### Header 4", 'id': 'aa6fc9dd-3283-43c9-a3e5-c68ad73efc03'},
                {'type': 'citation', 'value': {'citation': 'https://en.wikipedia.org/wiki/Maxwell%27s_equations, accessed 21.12.2022.', 'link': '', 'label': 'cite1'}, 'id': '046a8885-c8d4-4cb2-af23-689d02df87cc'},
                {'type': 'text', 'value': '## Header 2\r\n##### Header 5\r\nWe start with the Accordion block, which is used to create verically collapsible content. In WaggyLabs, its customization allows to either keep only one accordion item open as on this page, or keep opened ones always open unless they have been manually collapsed. Various items can be added into an accordion item including quote, picture carousel, citation, embed, equation, figure, listing, table.', 'id': 'c09de4fe-414a-4657-9af9-5b5e0fe97897'},
                {'type': 'accordion', 'value': {'style': 'collapsible', 'items': [{'type': 'item', 'value': {'heading': 'Accordion item 1', 'header_icon': 'briefcase fill', 'header_icon_location': 'end', 'is_open': True, 'body': [{'type': 'figure', 'value': {'image': 1, 'caption': 'Picture 1 included in the accordion item 1. It has long long long long long long long long long long long long long long long long  cpation for sidebar testing.', 'label': 'fig1'}, 'id': '232e0e00-6cd2-4bdc-b642-6e6c50e06f3d'}]}, 'id': 'e9cbcb93-5811-4513-a2df-513e18e3fc2e'}, {'type': 'item', 'value': {'heading': 'Accordion Item 2', 'header_icon': '', 'header_icon_location': '', 'is_open': False, 'body': [{'type': 'text', 'value': 'Again text block within Accordion block is **Markdown** text block, in which any type of markdown syntax can be used. \r\n\r\nIt is as well possible to give references to quotes, figures, tables, listings, equations using standard TeX style \\ref{fig1} syntax and cite literaterature\\cite{cite2}.\r\n\r\nMore than one accordion item can be selected to be expanded when the page is first loaded.\r\n\r\nIn this accordion item only two text blocks and one citation blocks are added.', 'id': 'dd742b0c-2df8-4b18-ad49-5e5e6cbb769e'}, {'type': 'citation', 'value': {'citation': 'Author A, Author B, Title, Issue, Year.', 'link': '', 'label': 'cite2'}, 'id': '161df629-5a47-4af1-b7a8-eeb11e586fa5'}]}, 'id': 'f32e0bbe-09b1-42da-958c-c06953bdebed'}, {'type': 'item', 'value': {'heading': 'Accordion item 3', 'header_icon': 'journal code', 'header_icon_location': '', 'is_open': True, 'body': [{'type': 'listing', 'value': {'code': {'mode': 'text/x-python', 'code': """class CardGridBlock(StructBlock):\r\n    height_style = ChoiceBlock(\r\n        choices=[\r\n            ('', _('Choose height style')),\r\n            ('equal', _('Equal height')),\r\n            ('not_equal', _('Height wraps to content')),\r\n        ],\r\n        default='',\r\n        label=_('Height'),\r\n        widget=DisabledOptionSelect,\r\n    )\r\n    grouping_style = ChoiceBlock(\r\n        choices=[\r\n            ('', _('Choose grouping style')),\r\n            ('separate', _('Separate')),\r\n            ('grouped', _('Grouped')),\r\n        ],\r\n        default='',\r\n        label=_('Grouping'),\r\n        widget=DisabledOptionSelect,\r\n    )\r\n    orientation_style = ChoiceBlock(\r\n        choices=[\r\n            ('', _('Choose orientation')),\r\n            ('vertical', _('Vertical')),\r\n            ('horizontal', _('Horizontal')),\r\n        ],\r\n        default='',\r\n        label=_('Orientation'),\r\n        widget=DisabledOptionSelect,\r\n    )\r\n    columns = ChoiceBlock(\r\n        choices=[\r\n            ('', _('Choose columns')),\r\n(1, _('1 column')),\r\n        ] + [\r\n            (i + 1, str(i + 1) + _(' columns')) for i in\r\n            range(1, (settings.WAGGYLABS_CARD_GRID_COLUMNS if\r\n                      hasattr(settings, 'WAGGYLABS_CARD_GRID_COLUMNS')\r\n                      else DEFAULT_CARD_GRID_COLUMNS))\r\n        ],\r\n        default='',\r\n        label=_('Number of columns'),\r\n    )\r\n    cards = ListBlock(CardBlock())\r\n    \r\n    class Meta:\r\n        icon = 'form'\r\n        label = _('Card grid')\r\n        template = 'waggylabs/frontend_blocks/card_grid.html'\r\n        form_template = 'waggylabs/blocks/card_grid.html'\r\n        label_format = _('Card grid: {cards}')"""}, 'caption': 'Listing present the class for WaggyLabs card grid block.', 'label': 'lst1'}, 'id': '1d09357d-fd88-4661-9e5e-40f08e84a14e'}]}, 'id': '3ace227d-2636-41aa-8db6-ef95adf7834a'}]}, 'id': 'f6bce100-a781-4ca2-acbf-3a6ecd4d3a38'},
                {'type': 'blockquote', 'value': {'quote': 'This is blockquote. Its settings allow to align text differently and add the quote icon. Quote can be as well referenced within other text blocks and include equations.', 'author': 'Quote Author', 'source': 'Quote Source', 'label': 'quote1', 'aligntment': 'text-end', 'show_icon': True}, 'id': '6f42d71d-d88f-424b-92c0-988395e2634e'},
                {'type': 'text', 'value': 'The next block is card grid. It can be used to display ordered items with the primary idea to create brief introduction to the research group personnel. Each card item can include photo, general information, links to other website contact information. Card grid has different styles including different number of columns, horizontal or vertical orientation of cards, grouping style. Below vertical separate cards organized in 3 colums are depicted.', 'id': '11ae4bac-7b57-45c7-a42c-2410ed06152f'},
                {'type': 'card_grid', 'value': {'height_style': '', 'grouping_style': 'separate', 'orientation_style': 'vertical', 'columns': '3', 'items': [{'type': 'item', 'value': {'image': 2, 'style': 'text-bg-success', 'title': 'Card Title 1', 'subtitle': 'Card Subtitle 1', 'alignment': '', 'text': 'Each card in the grid can include picture, title, subtitle and text again with support of equations: $\\exp{i\\pi}+1=0$. At the bottom of the card links and contact information can be added.', 'links': [{'type': 'external_link', 'value': {'link': 'http://twitter.com', 'text': '@twitter', 'icon': 'twitter', 'icon_location': '', 'style': 'btn btn-outline-primary'}, 'id': 'c2782fce-f99a-401a-8c78-ca5a435ad97b'}, {'type': 'internal_link', 'value': {'link': 4, 'text': 'Home page', 'icon': 'currency euro', 'icon_location': '', 'style': 'nav-link link-success'}, 'id': '82a5f25d-b370-4ad3-b6b3-272e2e66937f'}]}, 'id': '47c3072e-35a6-40f3-b751-647baf26e8a8'}, {'type': 'item', 'value': {'image': 3, 'style': 'border-warning', 'title': 'Card 2', 'subtitle': '', 'alignment': '', 'text': 'Pharetra vel turpis nunc eget lorem dolor. Condimentum id venenatis a condimentum. Rhoncus urna neque viverra justo nec ultrices dui sapien eget. Venenatis urna cursus eget nunc scelerisque viverra mauris. Lorem dolor sed viverra ipsum nunc aliquet. Enim facilisis gravida neque convallis a cras. Etiam non quam lacus suspendisse faucibus interdum posuere lorem. Nisi vitae suscipit tellus mauris. A erat nam at lectus urna duis. Habitasse platea dictumst vestibulum rhoncus est. Mauris pharetra et ultrices neque. Nullam eget felis eget nunc lobortis mattis. Lectus quam id leo in. Amet mauris commodo quis imperdiet massa tincidunt nunc pulvinar sapien. Scelerisque purus semper eget duis at tellus.', 'links': [{'type': 'email', 'value': {'email': 'mail@example.com', 'text': 'email', 'icon': 'envelope at', 'icon_location': 'end', 'style': 'btn btn-warning'}, 'id': 'ea200b46-d4dd-4605-b6e7-c373fcac9386'}]}, 'id': '6e2c215f-c959-4618-a8b1-35e8b59deb92'}, {'type': 'item', 'value': {'image': 4, 'style': '', 'title': 'Card 4', 'subtitle': '', 'alignment': '', 'text': '', 'links': [{'type': 'info_text', 'value': {'text': 'Mars Platet', 'style': 'btn btn-info', 'icon': 'globe asia australia', 'icon_location': ''}, 'id': '42d7e70d-acb3-47a0-a150-981e19e88028'}]}, 'id': 'b589fc94-9ad9-4591-bbb2-d8e59698f6f8'}, {'type': 'item', 'value': {'image': None, 'style': 'border-0', 'title': 'Card 4', 'subtitle': 'Card 4 Subtitle', 'alignment': 'text-end', 'text': 'Ac ut consequat semper viverra nam. Fermentum dui faucibus in ornare quam. Egestas erat imperdiet sed euismod nisi porta lorem mollis aliquam. Porttitor lacus luctus accumsan tortor posuere ac ut consequat semper. Interdum velit laoreet id donec ultrices tincidunt. Mattis enim ut tellus elementum sagittis. Tristique magna sit amet purus gravida quis. Lobortis feugiat vivamus at augue eget arcu dictum. Amet justo donec enim diam vulputate ut pharetra. Pretium viverra suspendisse potenti nullam ac tortor vitae. Non odio euismod lacinia at. Euismod quis viverra nibh cras pulvinar. Vitae sapien pellentesque habitant morbi. Lacinia quis vel eros donec ac. Malesuada proin libero nunc consequat interdum. Turpis massa sed elementum tempus egestas sed. Mi tempus imperdiet nulla malesuada pellentesque elit eget. Curabitur gravida arcu ac tortor dignissim convallis aenean et tortor. Lectus magna fringilla urna porttitor rhoncus.', 'links': [{'type': 'info_text', 'value': {'text': 'Give me a call', 'style': 'card-link', 'icon': 'telephone fill', 'icon_location': ''}, 'id': '21d5da85-0885-4701-81cd-1ebbc52017f6'}, {'type': 'external_link', 'value': {'link': 'http://example.com', 'text': '', 'icon': '', 'icon_location': '', 'style': 'link-danger'}, 'id': 'c8dd78c9-e92e-4b13-9600-8c11226426ee'}]}, 'id': '4abf55cf-bcb0-4e6a-8137-40d0c5743bda'}]}, 'id': '9b7e9370-4bf8-4a21-895d-51ff407611f9'},
                {'type': 'text', 'value': 'Now we switch to the picture carousel block. Its settings can be manipulated to select buttons, indicators, time to switch pictures (or not to switch them at all), switching style (slide or fade), color of text and buttons.', 'id': '1e454203-a0e1-48b7-827d-f8c7c7fe0843'},
                {'type': 'carousel', 'value': {'switch': 'carousel-fade', 'controls': 'buttons_indicators', 'items': [{'type': 'item', 'value': {'image': 1, 'caption': 'This is first picture of picture carousel. Of course, it can be with an equation: $\\text{e}^{i\\pi} + 1 = 0$.', 'interval': 5000, 'text_justify': 'text-center', 'text_color': 'text-dark', 'text_size': 'fs-5'}, 'id': '4c38eb3f-9149-49d5-a491-1e8cc777bff6'}, {'type': 'item', 'value': {'image': 5, 'caption': 'This is second picture of image carousel. Any *type* of **markdown** formatting can be used.', 'interval': 6000, 'text_justify': '', 'text_color': 'text-light', 'text_size': 'fs-4'}, 'id': 'f26c5b82-926a-41a9-a998-a2abde3f98ed'}, {'type': 'item', 'value': {'image': 6, 'caption': '', 'interval': 4000, 'text_justify': '', 'text_color': 'text-light', 'text_size': 'fs-6'}, 'id': 'c55b9a29-b832-4a9f-908a-b6319ca6dfec'}]}, 'id': '0bdfdade-64fa-4222-81f6-13534f62e31f'},
                {'type': 'text', 'value': 'Now we present the Columns block. Columns can display almost any block discussed on page. Maximum number of columns depends on the settings used to create WaggyLabs site in Python.', 'id': '75add1e2-246d-4c02-ab0c-b26373606ca4'},
                {'type': 'columns', 'value': {'items': [{'type': 'item', 'value': {'vertical_align': 'align-self-center', 'body': [{'type': 'accordion', 'value': {'style': 'collapsible', 'items': [{'type': 'item', 'value': {'heading': 'Accordion Item 1', 'header_icon': '', 'header_icon_location': '', 'is_open': True, 'body': [{'type': 'text', 'value': 'Vitae tortor condimentum lacinia quis. Ullamcorper sit amet risus nullam eget felis eget nunc lobortis. Nunc eget lorem dolor sed. Pulvinar pellentesque habitant morbi tristique senectus et netus et malesuada. Consequat interdum varius sit amet mattis vulputate enim. Quis auctor elit sed vulputate mi sit amet mauris commodo. Sed risus pretium quam vulputate dignissim suspendisse in. Ultrices dui sapien eget mi proin sed libero enim. Quisque egestas diam in arcu cursus euismod quis viverra nibh. Dolor magna eget est lorem ipsum dolor sit amet consectetur. Scelerisque viverra mauris in aliquam sem fringilla. Sit amet risus nullam eget felis eget nunc. Fermentum leo vel orci porta. Iaculis urna id volutpat lacus laoreet non. Mollis nunc sed id semper risus. Lobortis feugiat vivamus at augue eget arcu dictum varius duis. At ultrices mi tempus imperdiet nulla malesuada pellentesque elit eget. Ut aliquam purus sit amet luctus venenatis lectus\\cite{cite3}.', 'id': 'cffde3e1-fb80-4803-b947-4de49b0dcd15'}, {'type': 'document', 'value': {'document': 1, 'label': 'cite3'}, 'id': '7da9e36b-8dcd-4929-81cd-9213e9f038d8'}]}, 'id': 'c6ea814d-f3bc-4c9e-b8e5-0093ec682a4b'}, {'type': 'item', 'value': {'heading': 'Accordion item 2', 'header_icon': '', 'header_icon_location': '', 'is_open': False, 'body': [{'type': 'text', 'value': 'Venenatis lectus magna fringilla urna porttitor rhoncus. Amet consectetur adipiscing elit duis tristique. Ut eu sem integer vitae justo eget magna. Ultricies leo integer malesuada nunc. Nisi porta lorem mollis aliquam ut. Ut morbi tincidunt augue interdum velit euismod in. Imperdiet proin fermentum leo vel. Mauris nunc congue nisi vitae suscipit. Nunc sed velit dignissim sodales ut eu sem integer. Ultricies mi eget mauris pharetra et ultrices neque. In nulla posuere sollicitudin aliquam ultrices sagittis. Elementum pulvinar etiam non quam lacus suspendisse faucibus interdum posuere. Imperdiet dui accumsan sit amet nulla. Maecenas volutpat blandit aliquam etiam erat velit scelerisque. Id porta nibh venenatis cras sed felis eget velit. Massa eget egestas purus viverra. Maecenas sed enim ut sem. Nec nam aliquam sem et tortor consequat id porta nibh \\cite{cite4,cite3}.', 'id': 'a1352519-bbd3-48ec-a42f-c57cb3f6e507'}, {'type': 'citation', 'value': {'citation': 'Author C, Author D, Title 2, Issue 2, Year 2.', 'link': '', 'label': 'cite4'}, 'id': '055413e6-1bda-4f81-a358-0aa299dcecc3'}]}, 'id': '14fc6a21-52e6-4f7a-a48b-7967ee8bc4a8'}]}, 'id': '22018fef-98bf-42af-a628-0340b4c5b7fd'}]}, 'id': 'de4251d6-18f9-4c02-bf4e-d3f380a9d39f'}, {'type': 'item', 'value': {'vertical_align': 'align-self-center', 'body': [{'type': 'collapse', 'value': {'text': 'Button to show hidden information', 'icon': 'arrow counterclockwise', 'icon_location': '', 'button_style': 'link-warning', 'style': 'border-danger', 'alignment': '', 'body': [{'type': 'text', 'value': 'Collape is the block to hide some information, which will be displayed by clicking the button. Collapse can contain any type of block except of Accordion. Testing citations\\cite{cite5,cite2}.', 'id': '017608d3-9cf2-49be-bb6d-3207ab8d6829'}, {'type': 'citation', 'value': {'citation': 'Author R, Author T, Interesting title, new year, new volume.', 'link': '', 'label': 'cite5'}, 'id': '6bb794c7-4943-4b8c-a812-df3fed36059a'}]}, 'id': '48946b8b-e7ff-436b-ae3e-15d503a61d32'}, {'type': 'table_figure', 'value': {'caption': 'Example table in the Collapse block.', 'image': 7, 'footer': '', 'label': ''}, 'id': '50021f6a-e1e8-40f5-a021-251e9d377c98'}]}, 'id': '3bd43820-bf0b-4f56-b5aa-2c65d8ad2147'}, {'type': 'item', 'value': {'vertical_align': 'align-self-center', 'body': [{'type': 'figure', 'value': {'image': 5, 'caption': 'Figure in the second column.', 'label': 'fig2'}, 'id': '5341dc8d-238e-4faf-83c7-50de8b202b1d'}]}, 'id': 'b3ab9cd3-5469-4768-8cce-0370fa86066c'}]}, 'id': '225de9d1-c94c-49ee-849c-b94ee45206d3'},
                {'type': 'text', 'value': 'Finally here come the "usual" blocks such as embeds (Embed \\ref{emb1}), standalone equations (Eqn. \\eqref{eq-Hall}, captions of such equations are only displayed when it is opened in a dialog for preview), figures (Figure\\ref{fig3}), and tables (Tables \\ref{tbl1} and \\ref{tbl2}).', 'id': 'aa4e8937-3cb6-4666-ab3d-99848a93f013'},
                {'type': 'embed', 'value': {'embed': 'https://www.youtube.com/watch?v=JqNg819PiZY', 'caption': 'A great lecture by prof. Leonard Susskind about Higgs boson.', 'label': 'emb1'}, 'id': 'dc4c059b-cbfa-4aab-be69-fc2aa8abd91c'},
                {'type': 'equation', 'value': {'equation': '\\begin{align}\r\n& E_y = B_0E_x\\frac{n_1q_1\\mu_1^2+n_2q_2\\mu_2^2}{n_1q_1\\mu_1+n_2q_2\\mu_2} = \\frac{B_0E_x}{\\sigma_0}\\left(n_1q_1\\mu_1^2+n_2q_2\\mu_2^2\\right), \\\\\r\n& j_x \\approx \\sigma_0 E_x,\\,\\text{and}\\, E_y = \\frac{B_0j_x}{\\sigma_0^2}\\left(n_1q_1\\mu_1^2+n_2q_2\\mu_2^2\\right).\r\n\\end{align}', 'caption': 'Electrc field and current in the Hall effect.', 'label': 'eq-Hall'}, 'id': 'ffacd476-15b0-494d-802b-74f5428e1b94'},
                {'type': 'figure', 'value': {'image': 6, 'caption': 'Caption if figure 3. $e^{i\\pi}+1=0$.', 'label': 'fig3'}, 'id': 'fd8c321a-322d-4c08-8b2a-ecb5d8b3140e'},
                {'type': 'table', 'value': {'caption': 'This is starndard table where cells can contain equations and markdown text. Also column and row headers as well as cell alignment can be configured.', 'table': {'data': [['', 'Col header 1', 'Col header 2', 'Col header 3'], ['Row header 1', '$\\text{e}^{i\\pi}+1=0$', '**bold text**', 'cell text'], ['Row header 2', '*italic text*', 'right aligned text', 'cell text']], 'cell': [], 'first_row_is_table_header': True, 'first_col_is_header': True, 'table_caption': ''}, 'footer': 'Footer of the table can include some text and equations as well.', 'label': 'tbl1'}, 'id': '635a5dbb-4886-4643-a176-f15a2d1f622e'},
                {'type': 'table_figure', 'value': {'caption': 'Table can be as well uploaded as figure.', 'image': 7, 'footer': 'Footer of the table.', 'label': 'tbl2'}, 'id': 'e1887ee1-4665-47f4-812c-f7fa8c8d545b'}
            ],
            is_lazy=True,
        ),
        sidebar=StreamValue(
            SidebarBlock(),
            [{'type': 'sidebar', 'value': {'style': 'sticky-top', 'items': [{'type': 'toc', 'value': {'header': 'Contents', 'header_icon': 'list nested', 'header_icon_location': '', 'header_style': 'h4', 'block_style': '', 'block_alignment': '', 'item': {'text_wrap': ''}}, 'id': '82cac2f0-2c16-4fd6-bb0a-6315bf5c98d4'}, {'type': 'link_list', 'value': {'header': 'Custom links', 'header_icon': 'link', 'header_icon_location': '', 'header_style': 'h3', 'block_style': 'border-0 mp-0', 'block_alignment': '', 'item': {'link_list_style': 'list-group', 'link_style': 'list-group-item list-group-item-action list-group-item-info', 'text_wrap': '', 'items': [{'type': 'external_link', 'value': {'link': 'http://twitter.com', 'text': 'twitter', 'icon': 'twitter', 'icon_location': '', 'style': 'link-success'}, 'id': '873c2188-b42c-44a4-88b8-1f17e9086980'}, {'type': 'internal_link', 'value': {'link': 4, 'text': 'Link to home page', 'icon': 'house check fill', 'icon_location': '', 'style': ''}, 'id': '4d70095d-2aaf-4663-957a-aa495f7b54ac'}]}}, 'id': '62bc8755-f4ff-4437-83f6-cc1ab6fccc62'}, {'type': 'page_info', 'value': {'header': 'Page info', 'header_icon': 'info circle fill', 'header_icon_location': '', 'header_style': 'h4', 'block_style': '', 'block_alignment': '', 'item': {'show_user': True, 'user_header': 'Author', 'show_avatar': False, 'avatar_location': 'start', 'show_email': False, 'email_header': '', 'show_first_published_at': True, 'first_published_at_header': 'Published', 'show_last_published_at': False, 'last_published_at_header': '', 'datetime_style': 'timesince', 'time_format': 'G:i', 'timesince_text': 'ago', 'alignment': '', 'row_header_style': 'fw-bold', 'row_data_style': 'fst-italic'}}, 'id': 'f452cb5f-5653-4b22-928b-66b266188e47'}, {'type': 'tabs', 'value': {'header': '', 'header_icon': '', 'header_icon_location': '', 'header_style': '', 'block_style': '', 'block_alignment': '', 'item': {'tabs_style': 'nav nav-tabs', 'buttons_style': '', 'tabs_font_size': 'fs-5', 'tabs_orientation': '', 'tabs_justify': 'justify-content-start', 'items': [{'type': 'toc', 'value': {'header': 'Contents', 'header_icon': 'list nested', 'header_icon_location': '', 'header_style': 'h5', 'block_style': '', 'block_alignment': '', 'item': {'text_wrap': ''}}, 'id': 'de926349-e5dc-46aa-aadf-cb946fbab055'}, {'type': 'visuals', 'value': {'header': 'Visuals', 'header_icon': 'card image', 'header_icon_location': '', 'header_style': 'h5', 'block_style': '', 'block_alignment': '', 'item': {'preview_buttons_text': 'Enlarge', 'preview_buttons_icon': 'arrows fullscreen', 'preview_buttons_icon_location': '', 'preview_buttons_style': '', 'include_embeds': True, 'include_equations': True, 'include_figures': True, 'include_listings': True, 'include_tables': True}}, 'id': '0b086195-8345-4ddb-bbaa-99faa0d598cd'}, {'type': 'citations', 'value': {'header': 'Refs', 'header_icon': 'book', 'header_icon_location': '', 'header_style': 'h5', 'block_style': '', 'block_alignment': '', 'item': {'text_wrap': ''}}, 'id': '9c59ad7f-bbfc-4c1f-9274-005f919c8a9c'}]}}, 'id': '011afd3e-eb6e-4d2b-8495-63f6b9144a9a'}]}, 'id': '383c0345-4352-4c77-9c67-c06601ed7ddf'}],
            is_lazy=True,
        ),
    )
    
    # Create a site with the new homepage set as the root
    Site.objects.create(hostname="localhost", root_page=sitepage, is_default_site=True)


def remove_sitepage(apps, schema_editor):
    # Get models
    ContentType = apps.get_model("contenttypes.ContentType")
    SitePage = apps.get_model("waggylabs.SitePage")

    # Delete the default sitepage
    # Page and Site objects CASCADE
    SitePage.objects.filter(slug="home", depth=2).delete()

    # Delete content type for sitepage model
    ContentType.objects.filter(model="sitepage", app_label="waggylabs").delete()


class Migration(migrations.Migration):

    # run_before = [
    #     ("wagtailcore", "0053_locale_model"),
    # ]

    dependencies = [
        # ("hitcount", "0004_auto_20200704_0933"),
        ("waggylabs", "0001_initial"),
    ]

    operations = [
        migrations.RunPython(create_sitepage, remove_sitepage),
    ]
